@@ -1,17 +1,21 @@
 testthat::test_that("Packages are installed", {
   testthat::skip_on_cran()
-  try(utils::remove.packages("disposables"))
-  modules::depend("disposables", "1.0.3", repos = "https://cloud.r-project.org")
-  testthat::expect_true(require("disposables"))
+  testthat::skip_on_ci()
+  testthat::skip_on_travis()
+  try(utils::remove.packages("knitr"))
+  modules::depend("knitr", "1.0.3", repos = "https://cloud.r-project.org")
+  testthat::expect_true(require("knitr"))
 })
 
 testthat::test_that("Throw errors", {
 
   testthat::skip_on_cran()
+  testthat::skip_on_ci()
+  testthat::skip_on_travis()
 
   testthat::expect_is(suppressWarnings(
     tmp <- try(modules::depend(
-      "disposables", "999",
+      "knitr", "999",
       repos = "https://cloud.r-project.org"),
       TRUE)
   ), "try-error")
@@ -19,7 +23,7 @@ testthat::test_that("Throw errors", {
 
   testthat::expect_is(suppressWarnings(
     tmp <- try(modules::depend(
-      "disposables999", "999",
+      "knitr999", "999",
       repos = "https://cloud.r-project.org"),
       TRUE)
   ), "try-error")
